@@ -153,7 +153,7 @@ class StreamInfo(MetadataBlock):
         f.write(struct.pack(">I", self.sample_rate >> 4)[-2:])
         # 4 bits sample, 3 channel, 1 bps
         byte = (self.sample_rate & 0xF) << 4
-        byte += ((self.channels - 1) & 3) << 1
+        byte += ((self.channels - 1) & 7) << 1
         byte += ((self.bits_per_sample - 1) >> 4) & 1
         f.write(chr(byte))
         # 4 bits of bps, 4 of sample count
@@ -517,7 +517,8 @@ class FLAC(FileType):
     """Known metadata block types, indexed by ID."""
 
     def score(filename, fileobj, header):
-        return header.startswith("fLaC")
+        return (header.startswith("fLaC") +
+                filename.lower().endswith(".flac") * 3)
     score = staticmethod(score)
 
     def __read_metadata_block(self, file):
@@ -580,11 +581,15 @@ class FLAC(FileType):
         fileobj = file(filename, "rb")
         try:
             self.__check_header(fileobj)
-            while self.__read_metadata_block(fileobj): pass
+            while self.__read_metadata_block(fileobj):
+                pass
+            if fileobj.read(2) != "\xff\xf8":
+                raise FLACNoHeaderError("End of metadata did not start audio")
         finally:
             fileobj.close()
 
-        try: self.metadata_blocks[0].length
+        try:
+            self.metadata_blocks[0].length
         except (AttributeError, IndexError):
             raise FLACNoHeaderError("Stream info block not found")
 
