@@ -70,11 +70,14 @@ class TASF(TestCase):
     def test_pprint(self):
         self.failUnless(self.audio.pprint())
 
-    def set_key(self, key, value, result=None):
+    def set_key(self, key, value, result=None, expected=True):
         self.audio[key] = value
         self.audio.save()
         self.audio = ASF(self.audio.filename)
         self.failUnless(key in self.audio)
+        self.failUnless(key in self.audio.tags)
+        self.failUnless(key in self.audio.tags.keys())
+        self.failUnless(key in self.audio.tags.as_dict().keys())
         newvalue = self.audio[key]
         if isinstance(newvalue, list):
             for a, b in zip(sorted(newvalue), sorted(result or value)):
@@ -148,6 +151,8 @@ class TASF(TestCase):
         self.failUnlessEqual(self.audio["QL/AllHaveStream"][1].stream, 2)
 
     def test_language(self):
+        self.failIf("QL/OneHasLang" in self.audio)
+        self.failIf("QL/AllHaveLang" in self.audio)
         self.audio["QL/OneHasLang"] = [
             ASFValue("Whee", UNICODE, language=2),
             ASFValue("Whee", UNICODE),
@@ -194,3 +199,27 @@ add(TASFTags2)
 class TASFTags3(TASF):
     original = os.path.join("tests", "data", "silence-3.wma")
 add(TASFTags3)
+
+class TASFIssue29(TestCase):
+    original = os.path.join("tests", "data", "issue_29.wma")
+    def setUp(self):
+        fd, self.filename = mkstemp(suffix='wma')
+        os.close(fd)
+        shutil.copy(self.original, self.filename)
+        self.audio = ASF(self.filename)
+
+    def tearDown(self):
+        os.unlink(self.filename)
+
+    def test_issue_29_description(self):
+        self.audio["Description"] = "Hello"
+        self.audio.save()
+        audio = ASF(self.filename)
+        self.failUnless("Description" in audio)
+        self.failUnlessEqual(audio["Description"], ["Hello"])
+        del(audio["Description"])
+        self.failIf("Description" in audio)
+        audio.save()
+        audio = ASF(self.filename)
+        self.failIf("Description" in audio)
+add(TASFIssue29)
