@@ -149,8 +149,8 @@ class TM4A(TestCase):
     def faad(self):
         if not have_faad: return
         value = os.system(
-            "faad -w %s > %s 2> %s" % (self.filename,
-                devnull, devnull))
+            "faad %s -o %s > %s 2> %s" % (
+                self.filename, devnull, devnull, devnull))
         self.failIf(value and value != NOTFOUND)
 
     def test_bitrate(self):
@@ -263,7 +263,7 @@ class TM4AHasTags(TM4A):
     def test_has_covr(self):
         self.failUnless('covr' in self.audio.tags)
         covr = self.audio.tags['covr']
-        self.failUnlessEqual(covr.format, M4ACover.FORMAT_PNG)
+        self.failUnlessEqual(covr.imageformat, M4ACover.FORMAT_PNG)
 
     def test_not_my_file(self):
         self.failUnlessRaises(
