@@ -154,7 +154,7 @@ class TMP4Tags(TestCase):
         data = Atom.render("data", "\x00\x00\x00\x00" + "\x00" * 4 + "whee")
         covr = Atom.render("covr", data)
         tags = self.wrap_ilst(covr)
-        self.failUnlessEqual(MP4Cover.FORMAT_JPEG, tags["covr"][0].format)
+        self.failUnlessEqual(MP4Cover.FORMAT_JPEG, tags["covr"][0].imageformat)
 
     def test_render_bool(self):
         self.failUnlessEqual(MP4Tags()._MP4Tags__render_bool('pgap', True),
@@ -228,9 +228,8 @@ class TMP4(TestCase):
 
     def faad(self):
         if not have_faad: return
-        value = os.system(
-            "faad -w %s > %s 2> %s" % (self.filename,
-                devnull, devnull))
+        value = os.system("faad %s -o %s > %s 2> %s" % (
+                self.filename, devnull, devnull, devnull))
         self.failIf(value and value != NOTFOUND)
 
     def test_score(self):
@@ -310,6 +309,10 @@ class TMP4(TestCase):
         if faad:
             self.faad()
 
+    def test_unicode(self):
+        self.set_key('\xa9nam', ['\xe3\x82\x8a\xe3\x81\x8b'],
+                     result=[u'\u308a\u304b'])
+
     def test_save_text(self):
         self.set_key('\xa9nam', [u"Some test name"])
 
@@ -464,7 +467,7 @@ class TMP4(TestCase):
         bb = self.__read_offsets(self.filename)
         for a, b in zip(aa, bb):
             self.failUnlessEqual(a, b)
-        
+
     def test_mime(self):
         self.failUnless("audio/mp4" in self.audio.mime)
 
@@ -491,8 +494,8 @@ class TMP4HasTags(TMP4):
         self.failUnless('covr' in self.audio.tags)
         covr = self.audio.tags['covr']
         self.failUnlessEqual(len(covr), 2)
-        self.failUnlessEqual(covr[0].format, MP4Cover.FORMAT_PNG)
-        self.failUnlessEqual(covr[1].format, MP4Cover.FORMAT_JPEG)
+        self.failUnlessEqual(covr[0].imageformat, MP4Cover.FORMAT_PNG)
+        self.failUnlessEqual(covr[1].imageformat, MP4Cover.FORMAT_JPEG)
 
     def test_not_my_file(self):
         self.failUnlessRaises(
@@ -543,6 +546,33 @@ class TMP4NoTags3G2(TMP4):
 
 add(TMP4NoTags3G2)
 
+class TMP4UpdateParents64Bit(TestCase):
+    original = os.path.join("tests", "data", "64bit.mp4")
+
+    def setUp(self):
+        fd, self.filename = mkstemp(suffix='.mp4')
+        os.close(fd)
+        shutil.copy(self.original, self.filename)
+
+    def test_update_parents(self):
+        file = open(self.filename)
+        atoms = Atoms(file)
+        self.assertEqual(77, atoms.atoms[0].length)
+        self.assertEqual(61, atoms.atoms[0].children[0].length)
+        tags = MP4Tags(atoms, file)
+        tags['pgap'] = True
+        tags.save(self.filename)
+        file = open(self.filename)
+        atoms = Atoms(file)
+        # original size + 'pgap' size + padding
+        self.assertEqual(77 + 25 + 974, atoms.atoms[0].length)
+        self.assertEqual(61 + 25 + 974, atoms.atoms[0].children[0].length)
+
+    def tearDown(self):
+        os.unlink(self.filename)
+
+add(TMP4UpdateParents64Bit)
+
 NOTFOUND = os.system("tools/notarealprogram 2> %s" % devnull)
 
 have_faad = True
